#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sorted-list
version:              0.2.3.1
visibility:           public
id:                   sorted-list-0.2.3.1-8C8E8v9lixLLe0zF39SovV
key:                  sorted-list-0.2.3.1-8C8E8v9lixLLe0zF39SovV
license:              MIT
maintainer:           Daniel Casanueva (coding `at` danielcasanueva.eu)
author:               Daniel Casanueva (coding `at` danielcasanueva.eu)
synopsis:             Type-enforced sorted lists and related functions.
description:
    Type-enforced sorted lists and related functions.

    These are useful for:

    * Constraining the argument of a function to be a sorted list
    by stating in your type that the input list is a sorted list.

    * Avoiding sorting a list twice.

    * Creating a list that is sorted from the moment of its construction,
    so it doesn'\''t have to be sorted later.

    * Performing list operations keeping the input list sorted.

    * Improving those list operations that can be
    benefited from the ordering of its elements.

    * Creating infinite lists that are sorted!

    * And more!

    If you are missing a feature, do not hesitate
    to ask by opening an issue at the bug-tracker.

category:             Data
abi:                  13c771bb5c05b2620f0ec20865b1f057
exposed:              True
exposed-modules:      Data.SortedList
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sorted-list-0.2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sorted-list-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sorted-list-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sorted-list
hs-libraries:         HSsorted-list-0.2.3.1-8C8E8v9lixLLe0zF39SovV
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:   /usr/share/doc/haskell-sorted-list/html/sorted-list.haddock
haddock-html:         /usr/share/doc/haskell-sorted-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

